@@ -2,7 +2,7 @@ fix_data <- function(x){
   data <- x$CALL$pars$data
   types <- c("data.frame", "matrix", "longitudinal", "list")
   cldata <- class(data)
-  if (!(cldata %in% types)) stop("The data class must be 'matrix', 'data.frame', 'longitudinal', or 'list' with entries the abovementioned data classes")
+  if (!any(cldata %in% types)) stop("The data class must be 'matrix', 'data.frame', 'longitudinal', or 'list' with entries the abovementioned data classes")
   if (cldata %in% types[1:3]){
     x <- pre_fix_data(x)
     if (!is.null(x$CALL$pars$covariates)){
